#
# spec file for package python-azure-keyvault
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-azure-keyvault
Version:        4.2.0
Release:        3.2
Summary:        Microsoft Azure Key Vault Client Library
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Azure/azure-sdk-for-python
Source:         https://files.pythonhosted.org/packages/source/a/azure-keyvault/azure-keyvault-%{version}.zip
Source1:        LICENSE.txt
BuildRequires:  %{python_module azure-keyvault-nspkg >= 1.0.0}
BuildRequires:  %{python_module azure-nspkg >= 3.0.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-azure-keyvault-certificates >= 4.4
Requires:       python-azure-keyvault-keys >= 4.5
Requires:       python-azure-keyvault-nspkg >= 1.0.0
Requires:       python-azure-keyvault-secrets >= 4.4
Requires:       python-azure-nspkg >= 3.0.0
Conflicts:      python-azure-sdk <= 2.0.0
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-azure-keyvault <= 4.2.0
%endif
BuildArch:      noarch

%python_subpackages

%description
This is the Microsoft Azure Key Vault libraries bundle.

This package does not contain any code in itself. It installs a set
of packages that provide APIs for Key Vault operations:

- azure-keyvault-keys
- azure-keyvault-secrets
- azure-keyvault-certificates

%prep
%setup -q -n azure-keyvault-%{version}

%build
install -m 644 %{SOURCE1} %{_builddir}/azure-keyvault-%{version}
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{python_expand # delete common files
rm -rf %{buildroot}%{$python_sitelib}/azure/keyvault/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/keyvault/__pycache__
rm -rf %{buildroot}%{$python_sitelib}/azure/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/__pycache__
}

%files %{python_files}
%license LICENSE.txt
%doc CHANGELOG.md README.md
%{python_sitelib}/azure_keyvault-*.dist-info

%changelog
* Fri May  3 2024 Robert Schweikert <rjschwei@suse.com>
- Change version setting of Obsoletes to <= to trigger python3
  binary removal since there was no source version bump
* Thu Apr  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch package to modern Python Stack on SLE-15
  + Use Python 3.11 on SLE-15 by default
  + Add Obsoletes for old python3 package on SLE-15
  + Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
  + Update name for dist directory in %%files section
- Drop setting default file attributes in %%files section
* Wed Mar 30 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 4.2.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Nov 26 2020 Robert Schweikert <rjschwei@suse.com>
- Only build Python3 flavors for distributions 15 and greater
* Thu Apr 30 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 4.1.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Add CHANGELOG.md and README.md to %%doc in %%files section
- Update Requires from setup.py
* Fri Jan 17 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 4.0.0
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Update Requires from setup.py
- Update %%description from README.rst
* Fri Oct  4 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Convert package to use namespace package for keyvault
  + Add python-azure-keyvault-nspkg to BuildRequires and Requires
  + Remove common files from keyvault namespace in %%install
- Drop patch to support older versions of setuptools as
  SLE-12 is now shipping with a recent enough version
  + ak_drop-compatible-releases-operator.patch
* Thu Apr 11 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Bump minimum version for namespace packages
  to 3.0.0 in BuildRequires and Requires
- Remove python-devel package from BuildRequires
- Run fdupes to hardlink duplicate files
  + Add fdupes to BuildRequires
  + Add %%fdupes invocation to %%install
* Mon Sep  3 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.1.0
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Move LICENSE.txt from %%doc to %%license section
- Refresh patches for new version
  + ak_drop-compatible-releases-operator.patch
- Update Requires from setup.py
- Update %%description from setup.py
* Mon Jan 29 2018 adrian.glaubitz@suse.com
- Install HISTORY.rst into doc directory
* Wed Oct  4 2017 adrian.glaubitz@suse.com
- Add namespace packages to BuildRequires
- Remove namespace files in %%install target
- Explicitly specify Python files of the package in %%files
* Mon Oct  2 2017 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.3.7
- Remove versioning for namespace packages in Requires
- Update Requires from setup.py
- Refresh patches for new version
  + ak_drop-compatible-releases-operator.patch
* Thu Jul 13 2017 adrian.glaubitz@suse.com
- Add python-azure-nspkg to Requires
* Tue Jun 27 2017 adrian.glaubitz@suse.com
- Initial build
  + Version 0.3.5
- Add patch to drop compatible releases operator from setup.py,
  required for SLES12 as the setuptools version is too old
  + ak_drop-compatible-releases-operator.patch
